pub struct RustExpr(/* private fields */);Expand description
Rust expression syntax stored as static metadata.
Implementations
Sourceimpl RustExpr
impl RustExpr
Sourcepub fn new(value: &'static str) -> Result<Self, RustSyntaxError>
pub fn new(value: &'static str) -> Result<Self, RustSyntaxError>
Validates Rust expression syntax stored as static metadata.
Errors
Returns RustSyntaxError when value is not valid Rust expression
syntax.
Sourcepub const fn from_macro_tokens_unchecked(value: &'static str) -> Self
pub const fn from_macro_tokens_unchecked(value: &'static str) -> Self
Stores Rust expression syntax emitted by a trusted macro expansion.
Sourcepub fn parse(self) -> Result<Expr, RustSyntaxError>
pub fn parse(self) -> Result<Expr, RustSyntaxError>
Parses the stored Rust expression syntax.
Errors
Returns RustSyntaxError when the stored string is not valid Rust
expression syntax.