pub struct RustType(/* private fields */);Expand description
Rust type syntax stored as static metadata.
Implementations
Sourceimpl RustType
impl RustType
Sourcepub fn new(value: &'static str) -> Result<Self, RustSyntaxError>
pub fn new(value: &'static str) -> Result<Self, RustSyntaxError>
Validates Rust type syntax stored as static metadata.
Errors
Returns RustSyntaxError when value is not valid Rust type syntax.
Sourcepub fn new_opt(
value: Option<&'static str>,
) -> Result<Option<Self>, RustSyntaxError>
pub fn new_opt( value: Option<&'static str>, ) -> Result<Option<Self>, RustSyntaxError>
Validates optional Rust type syntax stored as static metadata.
Errors
Returns RustSyntaxError when value is Some and the contained
string is not valid Rust type syntax.
Sourcepub const fn from_macro_tokens_unchecked(value: &'static str) -> Self
pub const fn from_macro_tokens_unchecked(value: &'static str) -> Self
Stores Rust type syntax emitted by a trusted macro expansion.
Sourcepub const fn from_macro_tokens_opt_unchecked(
value: Option<&'static str>,
) -> Option<Self>
pub const fn from_macro_tokens_opt_unchecked( value: Option<&'static str>, ) -> Option<Self>
Stores optional Rust type syntax emitted by a trusted macro expansion.
Sourcepub fn parse(self) -> Result<Type, RustSyntaxError>
pub fn parse(self) -> Result<Type, RustSyntaxError>
Parses the stored Rust type syntax.
Errors
Returns RustSyntaxError when the stored string is not valid Rust type
syntax.