RustType

Struct RustType 

pub struct RustType(/* private fields */);
Rust type syntax stored as static metadata.

Implementations

Source

impl RustType

pub fn new(value: &'static str) -> Result<Self, RustSyntaxError>

Validates Rust type syntax stored as static metadata.

Errors

Returns RustSyntaxError when value is not valid Rust type syntax.

pub fn new_opt( value: Option<&'static str>, ) -> Result<Option<Self>, RustSyntaxError>

Validates optional Rust type syntax stored as static metadata.

Errors

Returns RustSyntaxError when value is Some and the contained string is not valid Rust type syntax.

pub const fn from_macro_tokens_unchecked(value: &'static str) -> Self

Stores Rust type syntax emitted by a trusted macro expansion.

pub const fn from_macro_tokens_opt_unchecked( value: Option<&'static str>, ) -> Option<Self>

Stores optional Rust type syntax emitted by a trusted macro expansion.

pub const fn as_str(self) -> &'static str

Returns the stored Rust type syntax.

pub fn parse(self) -> Result<Type, RustSyntaxError>

Parses the stored Rust type syntax.

Errors

Returns RustSyntaxError when the stored string is not valid Rust type syntax.